close all
clear all
clc

global Area Iy  Iz Dot Din Rot thickness theta PI

PI=3.1415926;
Dot=6.5;
Rot=Dot/2;
thickness=0.027;
Din=Dot-2*thickness;
Area=PI/4*(Dot*Dot-Din*Din);
Iy=PI/64*(Dot^4-Din^4);
Iz=Iy;
theta=270/180*PI;
Q=3000;

% Area=0.05089; % External area of the mooring line for 50 meters - chain
% PI=3.1415926;

%% User-defined input

folder = 'W:\200-100-50 SRA\FLS\50\8-1';
prefix = 'Analysis';
    
    % Read the RIFLEX force output file
    fname = 'analysis_elmfor.asc';
    data = load([folder '\' fname]);
    time_RIFLEX = data(:,1);           
    
     % Tower force
    TowerBaseAxial  = data(:,15);
    TowerBaseTors   = data(:,16);
    TowerBaseBMY    = data(:,17);
    TowerBaseBMZ    = data(:,19);
    TowerBaseShearY = data(:,21);
    TowerBaseShearZ = data(:,23);
    
    cikma=TowerBaseAxial./Area-TowerBaseBMY./Iy*Rot*sin(theta)+TowerBaseBMZ./Iz*Rot*cos(theta);
    cikma=cikma/1000;
    
    t_start = 400;
    indS = sum(time_RIFLEX<=t_start);

     x(:,1)=time_RIFLEX(indS:end);
     x(:,2)=cikma(indS:end);
     [tp ind] = dat2tp(x,0,'none');
     
     %dat2tp([t(skippt:endpt) v(skippt:endpt)],0,'none');
    
    def.res='CS';
    DEF.ASYMMETRIC=0;
    DEF.TIME=0;
    
    [RFC,RFC1,res,def]=tp2rfc(tp,def);
    %beta    
    beta=zeros(1,2);
    beta(1)=3.0;
    beta(2)=5.0;
    %K    
    K=zeros(1,2);
    K(1)=1/10^(12.164);
    K(2)=1/10^(15.606);
    
    %stresslim
    stresslim=52.63;

    %thk
    thk=thickness;

    %tref
    tref=0.025;

    %k
    k=0.2;

    D=cc2dam_2slope(RFC,beta,K,stresslim,thk,tref,k)
    
    %standard deviation of towerbase bending moment
    EMy=mean(TowerBaseBMY(indS:end))

    SDMy=std(TowerBaseBMY(indS:end))
    
    MAXy=max(TowerBaseBMY(indS:end))

    EMz=mean(TowerBaseBMZ(indS:end))

    SDMz=std(TowerBaseBMZ(indS:end))
    
    MAXz=max(TowerBaseBMZ(indS:end))
 
%==========================================================================    
    % mooring lines
    mooringline1tension  = data(:,2);
    mooringline2tension  = data(:,3);
    mooringline3tension  = data(:,4);
    
    cikma1=mooringline1tension/0.05089;
    cikma1=cikma1/1000;
    
    t_start = 400;
    indS = sum(time_RIFLEX<=t_start);

     x(:,1)=time_RIFLEX(indS:end);
     x(:,2)=cikma1(indS:end);
     [tp ind] = dat2tp(x,0,'none');
     
    %x(:,1)=time_RIFLEX;
    %x(:,2)=cikma;
   
    %dat2tp([t(skippt:endpt) v(skippt:endpt)],0,'none');
    
    def.res='CS';
    DEF.ASYMMETRIC=0;
    DEF.TIME=0;
    
    [RFC,RFC1,res,def]=tp2rfc(tp,def);
%beta    
    beta=3.0;
    
%K    
    K=1/10^(10.78);
    D1=cc2dam(RFC,beta,K)
 
%==========================================================================    
%standard deviation 
ET1=mean(mooringline1tension(indS:end))
SDT1=std(mooringline1tension(indS:end))
MAXT1=max(mooringline1tension(indS:end))

%==========================================================================
% Plot the time series 
figure
plot(time_RIFLEX(indS:end),mooringline1tension(indS:end))
xlabel('Time, s')
ylabel('mooringline1tension, kN')
xlim([t_start,4000])
%saveas(figure(1),'Tension1','jpg')
%==========================================================================

%==========================================================================
%S = dat2spec([time_SIMO PlatMotions],100,g,3,0.95,'cov','mean','w')
  
%==========================================================================
x=[time_RIFLEX(indS:end) mooringline1tension(indS:end)];
s=dat2spec2(mooringline1tension(indS:end),Q,'','','',0.1);
figure
plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
h = legend(' mooringline1tension spectrum',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',12);
xlim([0,1])
xlabel('Frequency [rad/s]','FontSize',14);
ylabel('mooringline1tension [KN^2 s/rad]','FontSize',14);
%saveas(figure(2),'tension1-spec','jpg')

    clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data','data2','samp')
    
%==========================================================================
  
    cikma2=mooringline2tension/0.05089;
    cikma2=cikma2/1000;
    
    t_start = 400;
    indS = sum(time_RIFLEX<=t_start);

     x(:,1)=time_RIFLEX(indS:end);
     x(:,2)=cikma2(indS:end);
     [tp ind] = dat2tp(x,0,'none');
     
    %x(:,1)=time_RIFLEX;
    %x(:,2)=cikma;
   
    %dat2tp([t(skippt:endpt) v(skippt:endpt)],0,'none');
    
    def.res='CS';
    DEF.ASYMMETRIC=0;
    DEF.TIME=0;
    
    [RFC,RFC1,res,def]=tp2rfc(tp,def);
%beta    
    beta=3.0; 
%K    
    K=1/10^(10.78);    
    D2=cc2dam(RFC,beta,K)

%==========================================================================    
%standard deviation & Mean value
ET2=mean(mooringline2tension(indS:end))
SDT2=std(mooringline2tension(indS:end))
MAXT2=max(mooringline2tension(indS:end))

%==========================================================================
% Plot the time series 
figure
plot(time_RIFLEX(indS:end),mooringline2tension(indS:end))
xlabel('Time, s')
ylabel('mooringline2tension, kN')
xlim([t_start,4000])
%saveas(figure(3),'Tension2','jpg')

%==========================================================================
%S = dat2spec([time_SIMO PlatMotions],100,g,3,0.95,'cov','mean','w')
  
%==========================================================================
x=[time_RIFLEX(indS:end) mooringline2tension(indS:end)];
s=dat2spec2(mooringline2tension(indS:end),Q,'','','',0.1);
figure
plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
h = legend(' mooringline2tension spectrum',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',12);
xlim([0,1])
xlabel('Frequency [rad/s]','FontSize',14);
ylabel('mooringline2tension [KN^2 s/rad]','FontSize',14);
%saveas(figure(4),'tension2-spec','jpg')

    clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data','data2','samp')
%==========================================================================   
  
    cikma3=mooringline3tension/0.05089;
    cikma3=cikma3/1000;
    
    t_start = 400;
    indS = sum(time_RIFLEX<=t_start);

     x(:,1)=time_RIFLEX(indS:end);
     x(:,2)=cikma3(indS:end);
     [tp ind] = dat2tp(x,0,'none');
     
    %x(:,1)=time_RIFLEX;
    %x(:,2)=cikma;
   
    %dat2tp([t(skippt:endpt) v(skippt:endpt)],0,'none');
    
    def.res='CS';
    DEF.ASYMMETRIC=0;
    DEF.TIME=0;
    
    [RFC,RFC1,res,def]=tp2rfc(tp,def);
%beta    
    beta=3.0;
%K    
    K=1/10^(10.78);
    D3=cc2dam(RFC,beta,K)       

%==========================================================================    
%standard deviation 
ET3=mean(mooringline3tension(indS:end))
SDT3=std(mooringline3tension(indS:end))
MAXT3=max(mooringline3tension(indS:end))

%==========================================================================
% Plot the time series 
figure
plot(time_RIFLEX(indS:end),mooringline3tension(indS:end))
xlabel('Time, s')
ylabel('mooringline3tension, kN')
xlim([t_start,4000])
%saveas(figure(5),'Tension3','jpg')

%==========================================================================
%S = dat2spec([time_SIMO PlatMotions],100,g,3,0.95,'cov','mean','w')
x=[time_RIFLEX(indS:end) mooringline3tension(indS:end)];
s=dat2spec2(mooringline3tension(indS:end),Q,'','','',0.1);
figure
plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
h = legend(' mooringline3tension spectrum',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',12);
xlim([0,1])
xlabel('Frequency [rad/s]','FontSize',14);
ylabel('mooringline3tension [KN^2 s/rad]','FontSize',14);
%saveas(figure(6),'tension3-spec','jpg')
      
    clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data','data2','samp')

    %==========================================================================

    % Read the SIMO output files
    MatFileName = [folder '\Semi.m'];
    fid = fopen(MatFileName);
    data = textscan(fid,'%s',12,'Delimiter','\n');
    data = data{1};

    % read time info
    for ii = 1:length(data)
       eval(data{ii}) ;
    end
    time_SIMO = Time.';
    clear('Time');

    % read data
    B = [1,2];
    for ii = 1:length(B)
         if (ii==1)
            R = 29;
        elseif (ii==2)
            R = 29;
        end
        for jj = 1:length(R)
            for kk = 1:6
                fname = (['B0' num2str(B(ii)) 'r' num2str(R(jj)) 'c00' num2str(kk)  ]);
                replaceinfile('\*\*\*\*\*\*\*\*\*\*\*','0.0',[folder '\' fname],'-nobak');
                load([folder '\' fname])
                eval(['var = ' fname ';']);
                for mm = 2:length(fname)-1
                   if fname(mm) == 0.0
                       fname(mm) = (fname(mm+1)+fname(mm-1))/2;
                   end
                end

            end
        end
    end 

    % summarize data in matrices
    PlatMotions = [B01r29c001 B01r29c002 B01r29c003 ...
        B01r29c004 B01r29c005 B01r29c006];
    NacMotions  = [B02r29c001 B02r29c002 B02r29c003 ...
        B02r29c004 B02r29c005 B02r29c006];
    
    % clear variables  
    for ii = 1:length(B)
        if (ii==1)
            R = 29;
        elseif (ii==2)
            R = 29;
        end
        for jj = 1:length(R)
            for kk = 1:6
                eval(['clear ''B0' num2str(B(ii)) 'r' num2str(R(jj)) ...
                    'c00' num2str(kk) ''';']); 
            end
        end
    end
    clear('B','R','MatFileName')

%==========================================================================    
%length of platform motion&rotor speed & tower base bending moment
%size_pm=size(PlatMotions,1);
%size_omega=length(omega);
%size_myz=length(TowerBaseBMY);

%mean of platform motions

Epm=mean(PlatMotions(indS:end,:));
Maxpm=max(PlatMotions(indS:end,:));
SDpm=std(PlatMotions(indS:end,:));
Minpm=min(PlatMotions(indS:end,:));

Esurge=Epm(1)
Maxsurge=Maxpm(1)
Minsurge=Minpm(1)
SDsurge=SDpm(1)
Esway=Epm(2)
Maxsway=Maxpm(2)
Minsway=Minpm(2)
SDsway=SDpm(2)
Eheave=Epm(3)
Maxheave=Maxpm(3)
Minheave=Minpm(3)
SDheave=SDpm(3)
Eroll=Epm(4)
Maxroll=Maxpm(4)
Minroll=Minpm(4)
SDroll=SDpm(4)
Epitch=Epm(5)
Maxpitch=Maxpm(5)
Minpitch=Minpm(5)
SDpitch=SDpm(5)
Eyaw=Epm(6)
Maxyaw=Maxpm(6)
Minyaw=Minpm(6)
SDyaw=SDpm(6)

%standard deviation of platform motions
% SDpm=std(PlatMotions(indS:end,:),0,1)

%==========================================================================
% Plot the time series of surge
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,1))
xlabel('Time, s')
ylabel('Surge, m')
xlim([t_start,4000])
%saveas(figure(7),'surge','jpg')

%==========================================================================
% Plot the time series of sway
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,2))
xlabel('Time, s')
ylabel('Sway, m')
xlim([t_start,4000])
%saveas(figure(8),'sway','jpg')

%==========================================================================
% Plot the time series of heave
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,3))
xlabel('Time, s')
ylabel('Heave, m')
xlim([t_start,4000])
%saveas(figure(9),'heave','jpg')

%==========================================================================
% Plot the time series of roll
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,4))
xlabel('Time, s')
ylabel('Roll, deg')
xlim([t_start,4000])
%saveas(figure(10),'roll','jpg')

%==========================================================================
% Plot the time series of pitch
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,5))
xlabel('Time, s')
ylabel('Pitch, deg')
xlim([t_start,4000])
%saveas(figure(11),'pitch','jpg')

%==========================================================================
% Plot the time series of yaw
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,6))
xlabel('Time, s')
ylabel('Yaw, deg')
xlim([t_start,4000])
%saveas(figure(12),'yaw','jpg')

  %Spectrum analysis
%==========================================================================
%S = dat2spec([time_SIMO PlatMotions],100,g,3,0.95,'cov','mean','w')
%==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,1)];
      s=dat2spec2(PlatMotions(indS:end,1),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' surge spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Surge [m^2 s/rad]','FontSize',14);
      xlim([0,0.5])
      %saveas(figure(13),'surge-spec','jpg')
           
%==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,2)];
      s=dat2spec2(PlatMotions(indS:end,2),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' sway spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Sway [m^2 s/rad]','FontSize',14);
      xlim([0,0.5])  
      %saveas(figure(14),'sway-spec','jpg')
%==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,3)];
      s=dat2spec2(PlatMotions(indS:end,3),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' heave spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Heave [m^2 s/rad]','FontSize',14);
      xlim([0,0.5])  
      %saveas(figure(15),'heave-spec','jpg')
 %==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,4)];
      s=dat2spec2(PlatMotions(indS:end,4),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' roll spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Roll [deg^2 s/rad]','FontSize',14);
      xlim([0,0.5])    
      %saveas(figure(16),'roll-spec','jpg')
 %==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,5)];
      s=dat2spec2(PlatMotions(indS:end,5),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' pitch spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Pitch [deg^2 s/rad]','FontSize',14);
      xlim([0,0.5])  
      %saveas(figure(17),'pitch-spec','jpg')
 %==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,6)];
      s=dat2spec2(PlatMotions(indS:end,6),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' yaw spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Yaw [deg^2 s/rad]','FontSize',14);
      xlim([0,0.5])     
      %saveas(figure(18),'yaw-spec','jpg')
      
%==========================================================================
  clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data','data2','samp')

    % Read the wind turbine results 
    % DLL output file
    fname = [folder '\DLL_WTdata.txt'];
    fid = fopen(fname);

    data = textscan(fid,'%f','Headerlines',1);
    data = data{1}; 
    data = (reshape(data,19,[])).';

    fclose(fid);
    time_DLL = data(:,1);
    HubWindX = data(:,2); % m/s
    HubWindY = data(:,3); % m/s
    HubWindZ = data(:,4); % m/s
    omega = data(:,6); % rad/s
    AeroForceX = data(:,8); % kN
    AeroMomX   = data(:,11); %kNm
    clear('data')
    
 % Riflex output file
     fname = [folder '\' prefix '_windturbine.asc'];
    fid = fopen(fname);
    data2 = textscan(fid,...
        '%f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f',...
        'Headerlines',2);
    fclose(fid);
    time_WTRIF = data2{1};
    BlPitch = data2{4};
    genTq = data2{5};
    genPwr = data2{6}*94.4/100; % generator efficiency included
    
    %mean and standard deviation of rotor speed, rpm
Eomega=mean(omega(indS:end))*30/3.1415926

SDomga=std(omega(indS:end),0,1);
%==========================================================================    
%mean generator power, kW
Epower=mean(genPwr(indS:end))
%==========================================================================    

Y = [D1; ET1; SDT1; MAXT1; 
     D2; ET2; SDT2; MAXT2;
     D3; ET3; SDT3; MAXT3;
     D; EMy; SDMy; MAXy;
        EMz; SDMz; MAXz;
     Esurge; Maxsurge; Minsurge; SDsurge; 
     Esway; Maxsway; Minsway; SDsway;
     Eheave; Maxheave; Minheave; SDheave;
     Eroll; Maxroll; Minroll; SDroll;
     Epitch; Maxpitch; Minpitch; SDpitch;
     Eyaw; Maxyaw; Minyaw; SDyaw;
     Eomega; Epower]


% Plot the time series of rotor speed
figure
plot(time_DLL(indS:end),omega(indS:end)*30/3.1415926)
xlabel('Time, s')
ylabel('Rotor speed, rpm')
xlim([t_start,4000])
%saveas(figure(19),'rotor speed','jpg')

%==========================================================================
% Plot the time series of generated power
figure
plot(time_WTRIF(indS:end),genPwr(indS:end))
xlabel('Time, s')
ylabel('Power, kW')
xlim([t_start,4000])
%saveas(figure(20),'power','jpg')

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))