% readSRAres  Reads in results from a single simulation 
% 

close all
clear all
clc

%% User-defined input
Q = 3000; % Parameter for spectrum analysis
folder = 'W:\200-100-50 SRA\ULS\200\90\ULS-2\SEED 10';
prefix = 'Analysis';

%% READ SIMULATION OUTPUT
%==========================================================================
%%READ SIMULATION OUTPUT
    % Read the SIMO output files
    MatFileName = [folder '\Semi.m'];
    fid = fopen(MatFileName);
    data = textscan(fid,'%s',12,'Delimiter','\n');
    data = data{1};

    % read time info
    for ii = 1:length(data)
       eval(data{ii}) ;
    end
    time_SIMO = Time.';
    clear('Time');

     % read data
    B = [1,2];
    for ii = 1:length(B)
         if (ii==1)
            R = 29;
        elseif (ii==2)
            R = 29;
        end
        for jj = 1:length(R)
            for kk = 1:6
                fname = (['B0' num2str(B(ii)) 'r' num2str(R(jj)) 'c00' num2str(kk)  ]);
                replaceinfile('\*\*\*\*\*\*\*\*\*\*\*','0.0',[folder '\' fname],'-nobak');
                load([folder '\' fname])
                eval(['var = ' fname ';']);
                for mm = 2:length(fname)-1
                   if fname(mm) == 0.0
                       fname(mm) = (fname(mm+1)+fname(mm-1))/2;
                   end
                end

            end
        end
    end 

    % summarize data in matrices
    PlatMotions = [B01r29c001 B01r29c002 B01r29c003 ...
        B01r29c004 B01r29c005 B01r29c006];
    NacMotions  = [B02r29c001 B02r29c002 B02r29c003 ...
        B02r29c004 B02r29c005 B02r29c006];
    
    % clear variables  
    for ii = 1:length(B)
        if (ii==1)
            R = 29;
        elseif (ii==2)
            R = 29;
        end
        for jj = 1:length(R)
            for kk = 1:6
                eval(['clear ''B0' num2str(B(ii)) 'r' num2str(R(jj)) ...
                    'c00' num2str(kk) ''';']); 
            end
        end
    end
    clear('B','R','MatFileName')
     
    % Read the RIFLEX force output file
    fname = 'analysis_elmfor.asc';
    data = load([folder '\' fname]);
    time_RIFLEX = data(:,1);      
    
      
    
    % Mooring line tension
    mooringline1tension = data(:,2);
    mooringline2tension = data(:,3);
    mooringline3tension = data(:,4);
    
    t_start = 400;
    indS = sum(time_RIFLEX<=t_start);

    
    %Read wave elevation information
   % fname = 'B01r02c001';
   % data = load([folder '\' fname]);
   % Waveelevation1 = data(:,1);
    
    %  fname = 'B04r02c001';
    % data = load([folder '\' fname]);
     % Waveelevation2 = data(:,1);
        
%==========================================================================    
%length of platform motion&rotor speed & tower base bending moment
%size_pm=size(PlatMotions,1);
%size_omega=length(omega);
%size_myz=length(TowerBaseBMY);

%mean of platform motions

Epm=mean(PlatMotions(indS:end,:));
Maxpm=max(PlatMotions(indS:end,:));
SDpm=std(PlatMotions(indS:end,:));
Minpm=min(PlatMotions(indS:end,:));

Esurge=Epm(1)
Maxsurge=Maxpm(1)
Minsurge=Minpm(1)
SDsurge=SDpm(1)
Esway=Epm(2)
Maxsway=Maxpm(2)
Minsway=Minpm(2)
SDsway=SDpm(2)
Eheave=Epm(3)
Maxheave=Maxpm(3)
Minheave=Minpm(3)
SDheave=SDpm(3)
Eroll=Epm(4)
Maxroll=Maxpm(4)
Minroll=Minpm(4)
SDroll=SDpm(4)
Epitch=Epm(5)
Maxpitch=Maxpm(5)
Minpitch=Minpm(5)
SDpitch=SDpm(5)
Eyaw=Epm(6)
Maxyaw=Maxpm(6)
Minyaw=Minpm(6)
SDyaw=SDpm(6)

  
%==========================================================================    
%standard deviation of mooring line tension
Emooring1=mean(mooringline1tension(indS:end))

SDmooring1=std(mooringline1tension(indS:end))

Maxmooring1=max(mooringline1tension(indS:end))

Emooring2=mean(mooringline2tension(indS:end));

SDmooring2=std(mooringline2tension(indS:end))

Maxmooring2=max(mooringline2tension(indS:end))

Emooring3=mean(mooringline3tension(indS:end))

SDmooring3=std(mooringline3tension(indS:end))

Maxmooring3=max(mooringline3tension(indS:end))

Y = [Emooring1; SDmooring1; Maxmooring1; 
     Emooring2; SDmooring2; Maxmooring2; 
     Emooring3; SDmooring3; Maxmooring3]
 
Z = [Esurge; Maxsurge; Minsurge; SDsurge; 
     Esway; Maxsway; Minsway; SDsway;
     Eheave; Maxheave; Minheave; SDheave;
     Eroll; Maxroll; Minroll; SDroll;
     Epitch; Maxpitch; Minpitch; SDpitch;
     Eyaw; Maxyaw; Minyaw; SDyaw]
 
%==========================================================================
% Plot the time series of mooringline 1 tension
figure
plot(time_RIFLEX(indS:end),mooringline1tension(indS:end))
xlabel('Time, s')
ylabel('Mooringline 1 Tension, KN')
xlim([t_start,4000])
%saveas(figure(1),'Tension1','jpg')

%==========================================================================
% Plot the time series of mooring line 2 tension
figure
plot(time_RIFLEX(indS:end),mooringline2tension(indS:end))
xlabel('Time, s')
ylabel('Mooringlien 2 Tension, KN')
xlim([t_start,4000])
%saveas(figure(2),'Tension2','jpg')

%==========================================================================
% Plot the time series of mooringline 3 tension
figure
plot(time_RIFLEX(indS:end),mooringline3tension(indS:end))
xlabel('Time, s')
ylabel('Mooringline 3 Tension, KN')
xlim([t_start,4000])
%saveas(figure(3),'Tension3','jpg')

%==========================================================================
% Plot the time series of surge
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,1))
xlabel('Time, s')
ylabel('Surge, m')
xlim([t_start,4000])
%saveas(figure(4),'surge','jpg')

%==========================================================================
% Plot the time series of sway
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,2))
xlabel('Time, s')
ylabel('Sway, m')
xlim([t_start,4000])
%saveas(figure(5),'sway','jpg')

%==========================================================================
% Plot the time series of heave
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,3))
xlabel('Time, s')
ylabel('Heave, m')
xlim([t_start,4000])
%saveas(figure(6),'heave','jpg')

%==========================================================================
% Plot the time series of roll
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,4))
xlabel('Time, s')
ylabel('Roll, deg')
xlim([t_start,4000])
%saveas(figure(7),'roll','jpg')

%==========================================================================
% Plot the time series of pitch
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,5))
xlabel('Time, s')
ylabel('Pitch, deg')
xlim([t_start,4000])
%saveas(figure(8),'pitch','jpg')

%==========================================================================
% Plot the time series of yaw
figure
plot(time_SIMO(indS:end),PlatMotions(indS:end,6))
xlabel('Time, s')
ylabel('Yaw, deg')
xlim([t_start,4000])
%saveas(figure(9),'yaw','jpg')

%Spectrum analysis
%==========================================================================
%S = dat2spec([time_SIMO PlatMotions],100,g,3,0.95,'cov','mean','w')
%==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,1)];
      s=dat2spec2(PlatMotions(indS:end,1),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' surge spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Surge [m^2 s/rad]','FontSize',14);
      xlim([0,3])
      %saveas(figure(10),'surge-spec','jpg')
           
%==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,2)];
      s=dat2spec2(PlatMotions(indS:end,2),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' sway spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Sway [m^2 s/rad]','FontSize',14);
      xlim([0,3])  
      %saveas(figure(11),'sway-spec','jpg')
%==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,3)];
      s=dat2spec2(PlatMotions(indS:end,3),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' heave spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Heave [m^2 s/rad]','FontSize',14);
      xlim([0,3])  
      %saveas(figure(12),'heave-spec','jpg')
 %==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,4)];
      s=dat2spec2(PlatMotions(indS:end,4),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' roll spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Roll [deg^2 s/rad]','FontSize',14);
      xlim([0,3])    
      %saveas(figure(13),'roll-spec','jpg')
 %==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,5)];
      s=dat2spec2(PlatMotions(indS:end,5),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' pitch spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Pitch [deg^2 s/rad]','FontSize',14);
      xlim([0,3])  
      %saveas(figure(14),'pitch-spec','jpg')
 %==========================================================================
      x=[time_SIMO(indS:end) PlatMotions(indS:end,6)];
      s=dat2spec2(PlatMotions(indS:end,6),Q,'','','',0.05);
      figure
      plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
      h = legend(' yaw spectrum',12);
      axis([0 8 0 inf])
      set(gca,'XTick',0:0.5:8)
      set(gca,'fontsize',12);
      xlabel('Frequency [rad/s]','FontSize',14);
      ylabel('Yaw [deg^2 s/rad]','FontSize',14);
      xlim([0,3])     
      %saveas(figure(15),'yaw-spec','jpg')
%==========================================================================

x=[time_RIFLEX(indS:end) mooringline1tension(indS:end)];
s=dat2spec2(mooringline1tension(indS:end),Q,'','','',0.1);
figure
plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
h = legend(' mooringline1tension spectrum',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',12);
xlim([0,2])
xlabel('Frequency [rad/s]','FontSize',14);
ylabel('mooringline1tension [KN^2 s/rad]','FontSize',14);
%saveas(figure(16),'tension1-spec','jpg')
%==========================================================================

x=[time_RIFLEX(indS:end) mooringline2tension(indS:end)];
s=dat2spec2(mooringline2tension(indS:end),Q,'','','',0.1);
figure
plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
h = legend(' mooringline2tension spectrum',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',12);
xlim([0,2])
xlabel('Frequency [rad/s]','FontSize',14);
ylabel('mooringline2tension [KN^2 s/rad]','FontSize',14);
%saveas(figure(17),'tension2-spec','jpg')
%==========================================================================

x=[time_RIFLEX(indS:end) mooringline3tension(indS:end)];
s=dat2spec2(mooringline3tension(indS:end),Q,'','','',0.1);
figure
plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
h = legend(' mooringline3tension spectrum',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',12);
xlim([0,2])
xlabel('Frequency [rad/s]','FontSize',14);
ylabel('mooringline3tension [KN^2 s/rad]','FontSize',14);
%saveas(figure(18),'tension3-spec','jpg')
%==========================================================================

% figure
%plot(time_SIMO(indS:end),Waveelevation1(indS:end))
%xlabel('Time, s')
%ylabel('wave elevation 1, m')
%xlim([t_start,4000])
%saveas(figure(19),'wave elevation 1','jpg')
%==========================================================================

%figure
%plot(time_SIMO(indS:end),Waveelevation2(indS:end))
%xlabel('Time, s')
%ylabel('wave elevation 2, m')
%xlim([t_start,4000])
%saveas(figure(20),'wave elevation 2','jpg')
%==========================================================================

%x=[time_SIMO(indS:end) Waveelevation2(indS:end)];
 %     s=dat2spec2(Waveelevation2(indS:end),Q,'','','',0.05);
  %    figure
   %   plot(s.w,s.S,'k-','LineWidth',1,'MarkerSize',1);
    %  h = legend(' wave spectrum',12);
     % axis([0 8 0 inf])
      %set(gca,'XTick',0:0.5:8)
      %set(gca,'fontsize',12);
      %xlabel('Frequency [rad/s]','FontSize',14);
      %ylabel('Wave Spectrum [m^2 s/rad]','FontSize',14);
      %xlim([0,3])  
      %saveas(figure(21),'wave-spec','jpg')
%==========================================================================

    clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data','data2','samp')
%%END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions, nacelle motions, and first order potential forces:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Nacelle positions :        NacMotions (mx6) : m,m,m,deg,deg,deg
%   1st order poten. forces:   PlatHydFor (mx6) : kN,kN,kN,kNm,kNm,kNm

% Wind turbine results (from RIFLEX output file): 
%   Time variable:             time_RIFWT (nx1) : s
%   Blade pitch:               BlPitch (nx1)    : deg
%   generator power :          genPwr (nx1)     : kW (94.4% efficiency INCLUDED) 
%   generator torque:          genTq (nx1)      : kNm (LSS side)

% Wind turbine results (from DLL output file): 
%   Time variable:             time_DLL (kx1)   : s
%   Thrust (global x):         AeroForceX (kx1) : kN
%   Aero. torque (glob x):     AeroMomX (kx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (glob x):       HubWindX (kx1)   : m/s (at hub pos)
%   Wind speed (glob y):       HubWindY (kx1)   : m/s (at hub pos)
%   Wind speed (glob z):       HubWindZ (kx1)   : m/s (at hub pos)

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))