% decay test analysis

function [b1,b2] = damp_coeff(tp,t,v,wn,FFT_tmax,tstart)

dtp = tp(2,1)-tp(1,1); 
dt = t(2)-t(1);
b1 = 0;
b2 = 0;
ind1 = sum(t<tstart);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% abs of peaks (ignore the last one)
phi_n = abs(tp(1:end-1,2));
tn = tp(1:end-1,1);

% potential energy at the peaks gives the decay
Vtn = wn^2*0.5*phi_n.^2; % eq 1.31
lnVtn = log(Vtn);
figure
semilogy(tn,Vtn,'.')
p = polyfit(tn,lnVtn,3); % fit a cubic polynomial
hold on 
semilogy(tn, exp(p(1)*tn.^3 + p(2)*tn.^2 + p(3)*tn.^1+ p(4)),'r')
xlabel('t, s')
ylabel('V_n')

P = (p(1)*tn.^3 + p(2)*tn.^2 + p(3)*tn + p(4));
dP = 3*p(1)*tn.^2 + 2*p(2)*tn.^1 + p(3);
L = -dP.*exp(P); % -dV/dt

A = ones(length(L),1);
B = sqrt(2)/pi*8/3*ones(length(L),1);
D = sqrt(Vtn).*B/wn;


Q = L./(2*wn*Vtn);
indices = 1:length(Vtn);%-5;

S1 = sum(A(indices).^2);
S2 = sum(A(indices).*D(indices));
S3 = sum(D(indices).^2);
S4 = sum(A(indices).*Q(indices));
S5 = sum(D(indices).*Q(indices));

b1s = (S3*S4-S2*S5)/(S1*S3-S2^2);
b2s = (S1*S5-S2*S4)/(S1*S3-S2^2);

b1 = 2*wn*b1s;
b2 = 2*b2s;
if b2<0
    disp('WARNING: negative b2');
    b2 = 0;abs(b2);
end

if b1<0
    disp('WARNING: negative b1');
    b1 = abs(b1);
end

% recreate the decay test using the computed coefficients
y0 = [v(ind1) 0];% Initial conditions
options = odeset('RelTol',1E-6,'AbsTol',1E-5);% set integration options
[T,Y] = ode45( @(t,x) quaddampedosc(t,x,wn,b1,b2),[0 800],y0);

f = figure;
set(f,'Position',[100 100 1200 300])
plot(t,v,'LineWidth',2)
hold on
plot(T+tstart,Y(:,1),'r--','LineWidth',2)
plot(tp(:,1),tp(:,2),'.')
set(gca,'FontSize',12)
set(gca,'GridLineStyle','--')
legend('Decay Test',['Recreated, b_1 = ' num2str(b1) ', b_2 = ' num2str(b2) ])
xlabel('Time, s')
xlim([0 FFT_tmax])

       
    
end
