% readSRAres  Reads in results from a single simulation 
% 

close all
clear all
clc

%% User-defined input
Q = 3000; % Parameter for spectrum analysis
folder = 'W:\200-100-50 SRA\200-100-50\ULS-1-45';
prefix = 'Analysis';

    % Read the RIFLEX force output file
    fname = '50-analysis_elmfor.asc';
    data = load([folder '\' fname]);
    time_RIFLEX = data(:,1);      
   
    % Mooring line tension
    mooringline1tension50 = data(:,2);
    mooringline2tension50 = data(:,3);
    mooringline3tension50 = data(:,4);
    
    t_start = 400;
    indS = sum(time_RIFLEX<=t_start);

    fname = '100-analysis_elmfor.asc';
    data = load([folder '\' fname]);
    
    mooringline1tension100 = data(:,2);
    mooringline2tension100 = data(:,3);
    mooringline3tension100 = data(:,4);
    
    fname = '200-analysis_elmfor.asc';
    data = load([folder '\' fname]);
    
    mooringline1tension200 = data(:,2);
    mooringline2tension200 = data(:,3);
    mooringline3tension200 = data(:,4);
    
    
    
    %Spectrum analysis
%==========================================================================
%S = dat2spec([time_SIMO PlatMotions],100,g,3,0.95,'cov','mean','w')
%==========================================================================

x=[time_RIFLEX(indS:end) mooringline1tension50(indS:end)];
s1=dat2spec2(mooringline1tension50(indS:end),Q,'','','',0.1);

y=[time_RIFLEX(indS:end) mooringline1tension100(indS:end)];
s2=dat2spec2(mooringline1tension100(indS:end),Q,'','','',0.1);

z=[time_RIFLEX(indS:end) mooringline1tension200(indS:end)];
s3=dat2spec2(mooringline1tension200(indS:end),Q,'','','',0.1);

figure

h=plot(s1.w,s1.S,'b-',s2.w,s2.S,'r-',s3.w,s3.S,'g-');
grid on

set(h(1),'linewidth',3);
set(h(2),'linewidth',3);
set(h(3),'linewidth',3);

h1 = legend(' 50 ',12, '100', 12, '200',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',16);
set(gca,'linewidth',5);
xlim([0,2])
xlabel('Frequency [rad/s]','FontSize',24);
title('mooringline1tension spectrum [KN^2 s/rad]','FontSize',32);

    %Spectrum analysis
%==========================================================================

x=[time_RIFLEX(indS:end) mooringline2tension50(indS:end)];
s1=dat2spec2(mooringline2tension50(indS:end),Q,'','','',0.1);

y=[time_RIFLEX(indS:end) mooringline2tension100(indS:end)];
s2=dat2spec2(mooringline2tension100(indS:end),Q,'','','',0.1);

z=[time_RIFLEX(indS:end) mooringline2tension200(indS:end)];
s3=dat2spec2(mooringline2tension200(indS:end),Q,'','','',0.1);

figure

h=plot(s1.w,s1.S,'b-',s2.w,s2.S,'r-',s3.w,s3.S,'g-');
grid on

set(h(1),'linewidth',3);
set(h(2),'linewidth',3);
set(h(3),'linewidth',3);


h1 = legend(' 50 ',12, '100', 12, '200',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',16);
set(gca,'linewidth',5);
xlim([0,2])
xlabel('Frequency [rad/s]','FontSize',24);
title('mooringline2tension spectrum [KN^2 s/rad]','FontSize',32);


    %Spectrum analysis
%==========================================================================

x=[time_RIFLEX(indS:end) mooringline3tension50(indS:end)];
s1=dat2spec2(mooringline3tension50(indS:end),Q,'','','',0.1);

y=[time_RIFLEX(indS:end) mooringline3tension100(indS:end)];
s2=dat2spec2(mooringline3tension100(indS:end),Q,'','','',0.1);

z=[time_RIFLEX(indS:end) mooringline3tension200(indS:end)];
s3=dat2spec2(mooringline3tension200(indS:end),Q,'','','',0.1);

figure

h=plot(s1.w,s1.S,'b-',s2.w,s2.S,'r-',s3.w,s3.S,'g-');
grid on


set(h(1),'linewidth',3);
set(h(2),'linewidth',3);
set(h(3),'linewidth',3);

h1 = legend(' 50 ',12, '100', 12, '200',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',16);
set(gca,'linewidth',5);
xlim([0,2])
xlabel('Frequency [rad/s]','FontSize',24);
title('mooringline3tension spectrum [KN^2 s/rad]','FontSize',32);

%saveas(figure(16),'tension1-spec','jpg')
%==========================================================================

% I'll just create an example
  
    
    
    clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data','data2','samp')
%%END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions, nacelle motions, and first order potential forces:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Nacelle positions :        NacMotions (mx6) : m,m,m,deg,deg,deg
%   1st order poten. forces:   PlatHydFor (mx6) : kN,kN,kN,kNm,kNm,kNm

% Wind turbine results (from RIFLEX output file): 
%   Time variable:             time_RIFWT (nx1) : s
%   Blade pitch:               BlPitch (nx1)    : deg
%   generator power :          genPwr (nx1)     : kW (94.4% efficiency INCLUDED) 
%   generator torque:          genTq (nx1)      : kNm (LSS side)

% Wind turbine results (from DLL output file): 
%   Time variable:             time_DLL (kx1)   : s
%   Thrust (global x):         AeroForceX (kx1) : kN
%   Aero. torque (glob x):     AeroMomX (kx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (glob x):       HubWindX (kx1)   : m/s (at hub pos)
%   Wind speed (glob y):       HubWindY (kx1)   : m/s (at hub pos)
%   Wind speed (glob z):       HubWindZ (kx1)   : m/s (at hub pos)

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))