% readSRAres  Reads in results from a single simulation 
% 

close all
clear all
clc

%% User-defined input
Q = 3000; % Parameter for spectrum analysis
folder = 'W:\200-100-50 SRA\200-100-50\ULS-2-90';
prefix = 'Analysis';

 MatFileName = [folder '\Semi.m'];
    fid = fopen(MatFileName);
    data = textscan(fid,'%s',12,'Delimiter','\n');
    data = data{1};

    % read time info
    for ii = 1:length(data)
       eval(data{ii}) ;
    end
    time_SIMO = Time.';
    clear('Time');
    
%Read motion information
    fname = '50-analysis_elmfor.asc';
    data = load([folder '\' fname]);
    time_RIFLEX = data(:,1); 
    
     t_start = 400;
    indS = sum(time_RIFLEX<=t_start);
    
    fname = '50-B01r29c002';
    data = load([folder '\' fname]);
    sway50 = data(:,1);
    
    fname = '50-B01r29c004';
    data = load([folder '\' fname]);
    roll50 = data(:,1);
    
    fname = '100-B01r29c002';
    data = load([folder '\' fname]);
    sway100 = data(:,1);
    
    fname = '100-B01r29c004';
    data = load([folder '\' fname]);
    roll100 = data(:,1);
      
    fname = '200-B01r29c002';
    data = load([folder '\' fname]);
    sway200 = data(:,1);
    
    fname = '200-B01r29c004';
    data = load([folder '\' fname]);
    roll200 = data(:,1);
    

%Spectrum analysis
%==========================================================================
%S = dat2spec([time_SIMO PlatMotions],100,g,3,0.95,'cov','mean','w')
%==========================================================================
%==========================================================================
 x=[time_SIMO(indS:end) sway50(indS:end)];
 s1=dat2spec2(sway50(indS:end),Q,'','','',0.05);

 y=[time_SIMO(indS:end) sway100(indS:end)];
 s2=dat2spec2(sway100(indS:end),Q,'','','',0.05);

z=[time_SIMO(indS:end) sway200(indS:end)];
 s3=dat2spec2(sway200(indS:end),Q,'','','',0.05);

figure

h=plot(s1.w,s1.S,'b-',s2.w,s2.S,'r-',s3.w,s3.S,'g-');
grid on

set(h(1),'linewidth',3);
set(h(2),'linewidth',3);
set(h(3),'linewidth',3);

h1 = legend(' 50 ',12, '100', 12, '200',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',16);
set(gca,'linewidth',4);
xlim([0,2])
xlabel('Frequency [rad/s]','FontSize',24);
title('sway spectrum [m^2 s/rad]','FontSize',32);  

%==========================================================================
 x=[time_SIMO(indS:end) roll50(indS:end)];
 s1=dat2spec2(roll50(indS:end),Q,'','','',0.05);

 y=[time_SIMO(indS:end) roll100(indS:end)];
 s2=dat2spec2(roll100(indS:end),Q,'','','',0.05);

z=[time_SIMO(indS:end) roll200(indS:end)];
 s3=dat2spec2(roll200(indS:end),Q,'','','',0.05);

figure

h=plot(s1.w,s1.S,'b-',s2.w,s2.S,'r-',s3.w,s3.S,'g-');
grid on

set(h(1),'linewidth',3);
set(h(2),'linewidth',3);
set(h(3),'linewidth',3);

h1 = legend(' 50 ',12, '100', 12, '200',12);
axis([0 8 0 inf])
set(gca,'XTick',0:0.5:8)
set(gca,'fontsize',16);
set(gca,'linewidth',4);
xlim([0,2])
xlabel('Frequency [rad/s]','FontSize',24);
title('roll spectrum [deg^2 s/rad]','FontSize',32);  

    clear('ii','jj','kk','mm','nsamp','start_time','end_time','var',...
        'fid','fname','data','data2','samp')
%%END READ SIMULATION OUTPUT

%==========================================================================

%% DESCRIPTION OF TIME SERIES available in the workspace
% =========================================================================
% Platform motions, nacelle motions, and first order potential forces:
%   Time variable:             time_SIMO (mx1)  : s
%   Platform positions:        PlatMotions (mx6): m,m,m,deg,deg,deg
%   Nacelle positions :        NacMotions (mx6) : m,m,m,deg,deg,deg
%   1st order poten. forces:   PlatHydFor (mx6) : kN,kN,kN,kNm,kNm,kNm

% Wind turbine results (from RIFLEX output file): 
%   Time variable:             time_RIFWT (nx1) : s
%   Blade pitch:               BlPitch (nx1)    : deg
%   generator power :          genPwr (nx1)     : kW (94.4% efficiency INCLUDED) 
%   generator torque:          genTq (nx1)      : kNm (LSS side)

% Wind turbine results (from DLL output file): 
%   Time variable:             time_DLL (kx1)   : s
%   Thrust (global x):         AeroForceX (kx1) : kN
%   Aero. torque (glob x):     AeroMomX (kx1)   : kNm (rotor inertia NOT INCLUDED) 
%   Wind speed (glob x):       HubWindX (kx1)   : m/s (at hub pos)
%   Wind speed (glob y):       HubWindY (kx1)   : m/s (at hub pos)
%   Wind speed (glob z):       HubWindZ (kx1)   : m/s (at hub pos)

% Internal force results at the tower base: 
%   Time variable:              time_RIFLEX (jx1)       : s
%   Axial force at tower base:  TowerBaseAxial (jx1)    : kN  (DOF1)
%   Bending mom. Y at tow base: TowerBaseBMY (jx1)      : kNm (DOF3)
%   Bending mom. Z at tow base: TowerBaseBMZ (jx1)      : kNm (DOF5)
%   Shear force Y at tow base:  TowerBaseShearY (jx1)   : kN  (DOF7)
%   Shear force Z at tow base:  TowerBaseShearZ (jx1)   : kN  (DOF9)
%   Torsional moment tow base:  TowerBaseTors (jx1)     : kNm (DOF2)

% =========================================================================
%% Post-processing
%  Statistical analysis, fatigue calculation, etc
%  Remember to cut out the first part of the time series
%  Hint: 
%           t_start = 400;
%           indS = sum(time_SIMO<=t_start);
%           mean(PlatMotions(indS:end))